aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMatthias Kretz <kretz@kde.org>2007-01-12 16:36:28 +0000
committerMatthias Kretz <kretz@kde.org>2007-01-12 16:36:28 +0000
commitf0c114351d0d63d0a649d8fd147b7c8e2f3cb502 (patch)
tree272742e53b9031940d4b4d8d8ce8d1f5606092c6
parentbba270ee7a936cac90eff98d9672d1ce60606c10 (diff)
downloadextra-cmake-modules-f0c114351d0d63d0a649d8fd147b7c8e2f3cb502.tar.gz
extra-cmake-modules-f0c114351d0d63d0a649d8fd147b7c8e2f3cb502.tar.bz2
- rename kalsadevicelist to kaudiodevicelist as it supports OSS devices just as
well now - adapt the KCM to the name change - make selections on the categoryTree work correctly (used the wrong signal) - added whatsThis and toolTips to the KCM - add unknown AudioCaptureDevices to the list - make the remove function use the standard removeRows function instead of replacing the whole model data - enable InternalMove on the deviceList svn path=/trunk/KDE/kdelibs/; revision=622681
-rw-r--r--modules/FindKDE4Internal.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/modules/FindKDE4Internal.cmake b/modules/FindKDE4Internal.cmake
index bf2160a5..b1ac495d 100644
--- a/modules/FindKDE4Internal.cmake
+++ b/modules/FindKDE4Internal.cmake
@@ -37,7 +37,7 @@
# KDE4_KDNSSD_LIBRARY - the kdnssd library
# KDE4_PHONONCORE_LIBRARY - the phononcore library
# KDE4_PHONONUI_LIBRARY - the phononui library
# KDE4_KALSADEVICELIST_LIBRARY - the kalsadevicelist library
# KDE4_KDEFX_LIBRARY - the kdefx library
# KDE4_THREADWEAVER_LIBRARY- the threadweaver library
# KDE4_SOLID_LIBRARY - the solid library
@@ -433,8 +433,8 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/kdecore/kernel/kglobal.h)
find_library(KDE4_PHONONUI_LIBRARY NAMES phononui PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
set(KDE4_PHONONUI_LIBS ${phononui_LIB_DEPENDS} ${KDE4_PHONONUI_LIBRARY} )
- find_library(KDE4_KALSADEVICELIST_LIBRARY NAMES kalsadevicelist PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
- set(KDE4_KALSADEVICELIST_LIBS ${kalsadevicelist_LIB_DEPENDS} ${KDE4_KALSADEVICELIST_LIBRARY} )
+ find_library(KDE4_KAUDIODEVICELIST_LIBRARY NAMES kaudiodevicelist PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
+ set(KDE4_KAUDIODEVICELIST_LIBS ${kaudiodevicelist_LIB_DEPENDS} ${KDE4_KAUDIODEVICELIST_LIBRARY} )
find_library(KDE4_SOLID_LIBRARY NAMES solid PATHS ${KDE4_LIB_INSTALL_DIR} )
set(KDE4_SOLID_LIBS ${solid_LIB_DEPENDS} ${KDE4_SOLID_LIBRARY} )
@@ -37,7 +37,7 @@
# KDE4_PHONONCORE_LIBRARY - the phononcore library
# KDE4_PHONONUI_LIBRARY - the phononui library
-# KDE4_KALSADEVICELIST_LIBRARY - the kalsadevicelist library
+# KDE4_KAUDIODEVICELIST_LIBRARY - the kaudiodevicelist library
# KDE4_KDEFX_LIBRARY - the kdefx library
# KDE4_THREADWEAVER_LIBRARY- the threadweaver library